@@ -1,4 +1,5 @@
 from interactor.request_handlers import CommandHandler, WSHandler
+from interactor.commander.animations import Animations
 
 from photons_app import helpers as hp
 
@@ -38,10 +39,14 @@ class Server(Server):
             ),
         ]
 
-    async def setup(self, server_options, sender, cleaners):
+    async def setup(self, server_options, *, tasks, sender, cleaners, animation_options=None):
         self.sender = sender
         self.cleaners = cleaners
         self.server_options = server_options
+        self.animation_options = animation_options
+
+        self.tasks = tasks
+        self.tasks._merged_options_formattable = True
 
         self.db_queue = __import__("interactor.database.db_queue").database.db_queue.DBQueue(
             self.final_future, 5, lambda exc: 1, self.server_options.database.uri
@@ -57,11 +62,19 @@ class Server(Server):
         self.cleaners.append(self.daemon.finish)
         await self.daemon.start()
 
+        self.animations = Animations(
+            self.final_future, self.tasks, self.sender, self.animation_options
+        )
+        self.animations._merged_options_formattable = True
+        self.cleaners.append(self.animations.stop)
+
         self.commander = Commander(
             self.store,
+            tasks=self.tasks,
             sender=self.sender,
             finder=self.finder,
             db_queue=self.db_queue,
+            animations=self.animations,
             final_future=self.final_future,
             server_options=self.server_options,
         )
